==> haskell-tamarin-prover-accountability-1.8.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-accountability
version:              1.8.0
visibility:           public
id:                   tamarin-prover-accountability-1.8.0-6T30GSmV2iE7h4MC2Ajj8l
key:                  tamarin-prover-accountability-1.8.0-6T30GSmV2iE7h4MC2Ajj8l
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  fd1b425a545d25288afb72327946c663
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.8.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.8.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.8.0-6T30GSmV2iE7h4MC2Ajj8l

depends:
    aeson-2.1.2.1-3hy4hA3togDsVnwRqQAZI
    aeson-pretty-0.8.10-EHbhnR4q86z8KHGoK5kE27 base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-JkQdhYNM3JJEdlX5hjsQCN mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay
    tamarin-prover-term-1.8.0-7kLm7IPpdwD32U2Y2lvkyc
    tamarin-prover-theory-1.8.0-uAtC1cAyKH88hfTRqkDK3
    tamarin-prover-utils-1.8.0-BjCPuIRZvNa1DgjVQPXXNd text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-2wlaKTDzX4U4sRJV09tewv

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-accountability-1.8.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-accountability.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-accountability
version:              1.8.0
visibility:           public
id:                   tamarin-prover-accountability-1.8.0-DNW5uHxf6SDBwhp8S2h9cc
key:                  tamarin-prover-accountability-1.8.0-DNW5uHxf6SDBwhp8S2h9cc
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  2ed240ecde105733c0e9fa4566483049
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.8.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tamarin-prover-accountability-1.8.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.8.0-DNW5uHxf6SDBwhp8S2h9cc

depends:
    aeson-2.1.2.1-CCP80pZvZcA8gRL3g3IUms
    aeson-pretty-0.8.10-3vsckJxgN154JV9gl4tkuC base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O exceptions-0.10.4
    fclabels-2.0.5.1-1on6OJsGJpvA7loLHZHEq2 mtl-2.2.2
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1 parsec-3.1.15.0
    process-1.6.16.0 raw-strings-qq-1.1-H0wHvIVgY406DfNVW3VYlH
    safe-0.3.21-FHqmWeL515h1ZDkEwV0YZX
    tamarin-prover-term-1.8.0-BsitReAwJ618Qnxmbb86D2
    tamarin-prover-theory-1.8.0-32pJnzrPZN28LZnzmiUIA9
    tamarin-prover-utils-1.8.0-KP3I2gl6oan1gwKHWe6y6x text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-E9XLtnRxE39Lc36BhbYiEq

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
